@@ -5,8 +5,24 @@ from django.contrib.sites.models import Site
 from django.contrib.auth import get_user_model
 
 from helpme.models import Ticket, Comment, Category, Question, Team, VisibilityChoices
+from helpme.utils import get_current_site
 
 
+class AnonymousTicketForm(ModelForm):
+    full_name = forms.CharField(label=_("Full Name"), widget=forms.TextInput(attrs={"placeholder": _("Enter name")}))
+    email = forms.EmailField(label=_("Email Address"), widget=forms.EmailInput(attrs={"placeholder": _("Enter email")}))
+    phone_number = forms.CharField(label=_("Phone Number (Optional)"), required=False)
+    
+    class Meta:
+        model = Ticket
+        fields = ['full_name', 'email', 'phone_number', 'description']
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.fields['description'].label = _("How Can We Help You?")
+        self.fields['description'].widget.attrs.update({'placeholder': _('Enter Message'), 'rows': 4})
+
+        
 class TicketForm(ModelForm):
 
     class Meta:
@@ -65,10 +81,11 @@ class QuestionForm(ModelForm):
         fields = ['question', 'answer', 'category']
 
     def __init__(self, *args, **kwargs):
+        self.request = kwargs.pop("request")
         super().__init__(*args, **kwargs)
 
         # limit the possible categories to the current site
-        current_site = Site.objects.get_current()
+        current_site = get_current_site(self.request)
         self.fields['category'].queryset = Category.objects.filter(category_sites__in=[current_site])
         self.fields['category'].label = _("Category")
 
